<TS language="es_DO" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Crear una nueva dirección</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Nuevo</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Copiar la dirección seleccionada al portapapeles del sistema</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Borrar de la lista la dirección seleccionada</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Eliminar</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Copiar &amp;etiqueta</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(sin etiqueta)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Diálogo de contraseña</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Introducir contraseña</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nueva contraseña</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Repita la nueva contraseña</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Cifrar la cartera</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Esta operación requiere su contraseña para desbloquear la cartera</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Desbloquear cartera</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Cambiar contraseña</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Introduzca la contraseña anterior de la cartera y la nueva. </translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Confirmar cifrado de la cartera</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>¿Seguro que desea cifrar su monedero?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Monedero cifrado</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>IMPORTANTE: Cualquier copia de seguridad que haya realizado previamente de su archivo de monedero debe reemplazarse con el nuevo archivo de monedero cifrado. Por razones de seguridad, las copias de seguridad previas del archivo de monedero no cifradas serán inservibles en cuanto comience a usar el nuevo monedero cifrado.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Ha fallado el cifrado del monedero</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Ha fallado el cifrado del monedero debido a un error interno. El monedero no ha sido cifrado.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Las contraseñas no coinciden.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Ha fallado el desbloqueo del monedero</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>La contraseña introducida para descifrar el monedero es incorrecta.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Se ha cambiado correctamente la contraseña del monedero.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Aviso: ¡La tecla de bloqueo de mayúsculas está activada!</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>Monedero</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Vista general</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Mostrar vista general del monedero</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Enviar</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Recibir</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Examinar el historial de transacciones</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Salir de la aplicación</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opciones...</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>Mo&amp;strar/ocultar</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Cifrar monedero…</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Cambiar la contraseña…</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Cambiar la contraseña utilizada para el cifrado del monedero</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Firmar &amp;mensaje...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Verificar mensaje...</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>Ventana de &amp;depuración</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Abrir la consola de depuración y diagnóstico</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuración</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>A&amp;yuda</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Actualizado</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Actualizando...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Transacción enviada</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Transacción entrante</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>El monedero está &lt;b&gt;cifrado&lt;/b&gt; y actualmente &lt;b&gt;bloqueado&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    <message>
        <source>Network Alert</source>
        <translation>Alerta de red</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Cantidad:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Cuantía:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Tasa:</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Envío pequeño:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Después de tasas:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Cambio:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Cantidad</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Confirmaciones</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmado</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copiar dirección</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copiar etiqueta</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copiar cantidad</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Copiar identificador de transacción</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Copiar cantidad</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Copiar donación</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Copiar después de aplicar donación</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Copiar bytes</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Copiar envío pequeño</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Copiar cambio</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>si</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(sin etiqueta)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>Enviar desde %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(cambio)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Editar Dirección</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etiqueta</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Dirección</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Nueva dirección de recepción</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nueva dirección de envío</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Editar dirección de recepción</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Editar dirección de envío</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>La dirección introducida "%1" ya está presente en la libreta de direcciones.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>No se pudo desbloquear el monedero.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Ha fallado la generación de la nueva clave.</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Principal</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Red</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Mapear el puerto usando &amp;UPnP</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Puerto:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Puerto del servidor proxy (ej. 9050)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
        <translation>Minimizar en lugar de salir de la aplicación al cerrar la ventana. Cuando esta opción está activa, la aplicación solo se puede cerrar seleccionando Salir desde el menú.</translation>
    </message>
    <message>
        <source>&amp;Display addresses in transaction list</source>
        <translation>&amp;Mostrar las direcciones en la lista de transacciones</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ventana</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Minimizar la ventana a la bandeja de iconos del sistema.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimizar a la bandeja en vez de a la barra de tareas</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimizar al cerrar</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Interfaz</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>I&amp;dioma de la interfaz de usuario</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>Mostrar las cantidades en la &amp;unidad:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Elegir la subdivisión predeterminada para mostrar cantidades en la interfaz y cuando se envían monedas.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>default</source>
        <translation>predeterminado</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>La dirección proxy indicada es inválida.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Desde</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Su balance actual gastable</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>No disponible:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Su balance actual total</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>N/D</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Versión del cliente</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Hora de inicio</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Número de conexiones</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Cadena de bloques</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Número actual de bloques</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Hora del último bloque</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Limpiar</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Consola</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Tráfico de Red</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Total:</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Dentro:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Fuera:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Archivo de registro de depuración</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Borrar consola</translation>
    </message>
    <message>
        <source>Estimated total blocks</source>
        <translation>Bloques totales estimados</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Nombre del cliente</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Use las flechas arriba y abajo para navegar por el historial y &lt;b&gt;Control+L&lt;/b&gt; para limpiar la pantalla.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Escriba &lt;b&gt;help&lt;/b&gt; para ver un resumen de los comandos disponibles.</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Enviar monedas</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Entradas...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>Seleccionado automaticamente</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Fondos insuficientes!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Cantidad:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Cuantía:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Tasa:</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Envío pequeño:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Después de tasas:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Enviar a múltiples destinatarios de una vez</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Añadir &amp;destinatario</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Limpiar &amp;todo</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Confirmar el envío</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;Enviar</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Copiar cantidad</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copiar cuantía</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Copiar donación</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Copiar después de aplicar donación</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Copiar bytes</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Copiar envío pequeño</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Copiar Cambio</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Confirmar el envío de monedas</translation>
    </message>
    <message>
        <source>The recipient address is not valid, please recheck.</source>
        <translation>La dirección de recepción no es válida, compruébela de nuevo.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>La cantidad por pagar tiene que ser mayor de 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>La cantidad sobrepasa su saldo.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>El total sobrepasa su saldo cuando se incluye la tasa de envío de %1</translation>
    </message>
    <message>
        <source>Duplicate address found, can only send to each address once per send operation.</source>
        <translation>Se ha encontrado una dirección duplicada. Solo se puede enviar a cada dirección una vez por operación de envío.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(sin etiqueta)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>Ca&amp;ntidad:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>&amp;Pagar a:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Mensaje:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etiqueta:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Pegar dirección desde portapapeles</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Etiquete esta dirección para añadirla a la libreta</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Firmas - Firmar / verificar un mensaje</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Firmar mensaje</translation>
    </message>
    <message>
        <source>You can sign messages with your addresses to prove you own them. Be careful not to sign anything vague, as phishing attacks may try to trick you into signing your identity over to them. Only sign fully-detailed statements you agree to.</source>
        <translation>Puede firmar mensajes con sus direcciones para demostrar que las posee. Tenga cuidado de no firmar cualquier cosa vaga, ya que los ataques de phishing pueden tratar de engañarle para suplantar su identidad. Firme solo declaraciones totalmente detalladas con las que usted esté de acuerdo.</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Pegar dirección desde portapapeles</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Introduzca el mensaje que desea firmar aquí</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Copiar la firma actual al portapapeles del sistema</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Firmar &amp;mensaje</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Limpiar todos los campos de la firma de mensaje</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Limpiar &amp;todo</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verificar mensaje</translation>
    </message>
    <message>
        <source>Enter the signing address, message (ensure you copy line breaks, spaces, tabs, etc. exactly) and signature below to verify the message. Be careful not to read more into the signature than what is in the signed message itself, to avoid being tricked by a man-in-the-middle attack.</source>
        <translation>Introduzca la dirección para la firma, el mensaje (asegurándose de copiar tal cual los saltos de línea, espacios, tabulaciones, etc.) y la firma a continuación para verificar el mensaje. Tenga cuidado de no asumir más información de lo que dice el propio mensaje firmado para evitar fraudes basados en ataques de tipo man-in-the-middle.</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Limpiar todos los campos de la verificación de mensaje</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Haga clic en "Firmar mensaje" para generar la firma</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>La dirección introducida es inválida.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Verifique la dirección e inténtelo de nuevo.</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>La dirección introducida no corresponde a una clave.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>Se ha cancelado el desbloqueo del monedero. </translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>No se dispone de la clave privada para la dirección introducida.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Ha fallado la firma del mensaje.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Mensaje firmado.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>No se puede decodificar la firma.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Compruebe la firma e inténtelo de nuevo.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>La firma no coincide con el resumen del mensaje.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>La verificación del mensaje ha fallado.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Mensaje verificado.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Abierto hasta %1</translation>
    </message>
    <message>
        <source>%1/offline</source>
        <translation>%1/fuera de línea</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/no confirmado</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 confirmaciones</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, todavía no se ha sido difundido satisfactoriamente</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Fuente</translation>
    </message>
    <message>
        <source>From</source>
        <translation>De</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>desconocido</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Para</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>dirección propia</translation>
    </message>
    <message>
        <source>label</source>
        <translation>etiqueta</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Crédito</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>no aceptada</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Débito</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Comisión de transacción</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Cantidad neta</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Mensaje</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Comentario</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Cantidad</translation>
    </message>
    <message>
        <source>true</source>
        <translation>verdadero</translation>
    </message>
    <message>
        <source>false</source>
        <translation>falso</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Detalles de transacción</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Esta ventana muestra información detallada sobre la transacción</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Cantidad</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Abierto hasta %1</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Confirmado (%1 confirmaciones)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Generado pero no aceptado</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Recibido con</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Recibidos de</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Enviado a</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Pago propio</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(nd)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Estado de transacción. Pasa el ratón sobre este campo para ver el número de confirmaciones.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Fecha y hora en que se recibió la transacción.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Tipo de transacción.</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>Dirección de destino de la transacción.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Cantidad retirada o añadida al saldo.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Hoy</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Esta semana</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Este mes</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Mes pasado</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Este año</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Rango...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Recibido con</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Enviado a</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>A usted mismo</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Minado</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Otra</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Cantidad mínima</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copiar dirección</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copiar etiqueta</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copiar cuantía</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Copiar identificador de transacción</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Editar etiqueta</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Mostrar detalles de la transacción</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmado</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Cantidad</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Rango:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>para</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv6, falling back to IPv4: %s</source>
        <translation>Ha ocurrido un error al configurar el puerto RPC %u para escuchar mediante IPv6. Recurriendo a IPv4: %s</translation>
    </message>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv4: %s</source>
        <translation>Ha ocurrido un error al configurar el puerto RPC %u para escucha en IPv4: %s</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Uso:</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>Muestra comandos
</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>Recibir ayuda para un comando
</translation>
    </message>
    <message>
        <source>Warning: -paytxfee is set very high! This is the transaction fee you will pay if you send a transaction.</source>
        <translation>Aviso: ¡-paytxfee tiene un valor muy alto! Esta es la comisión que pagará si envía una transacción.</translation>
    </message>
    <message>
        <source>Warning: wallet.dat corrupt, data salvaged! Original wallet.dat saved as wallet.{timestamp}.bak in %s; if your balance or transactions are incorrect you should restore from a backup.</source>
        <translation>Aviso: ¡Recuperados datos de wallet.dat corrupto! El wallet.dat original se ha guardado como wallet.{timestamp}.bak en %s; si hubiera errores en su saldo o transacciones, deberá restaurar una copia de seguridad.</translation>
    </message>
    <message>
        <source>Warning: error reading wallet.dat! All keys read correctly, but transaction data or address book entries might be missing or incorrect.</source>
        <translation>Aviso: ¡Error al leer wallet.dat! Todas las claves se han leído correctamente, pero podrían faltar o ser incorrectos los datos de transacciones o las entradas de la libreta de direcciones.</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Ha fallado la escucha en todos los puertos. Use -listen=0 si desea esto.</translation>
    </message>
    <message>
        <source>To use the %s option</source>
        <translation>Para utilizar la opción %s</translation>
    </message>
    <message>
        <source>You must set rpcpassword=&lt;password&gt; in the configuration file:
%s
If the file does not exist, create it with owner-readable-only file permissions.</source>
        <translation>Tiene que establecer rpcpassword=&lt;contraseña&gt; en el fichero de configuración: ?
%s ?
Si el archivo no existe, créelo con permiso de lectura solamente del propietario.</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>Cantidad inválida para -paytxfee=&lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>wallet.dat corrupt, salvage failed</source>
        <translation>wallet.dat corrupto. Ha fallado la recuperación.</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Dirección -proxy inválida: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -bind address: '%s'</source>
        <translation>No se puede resolver la dirección de -bind: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -externalip address: '%s'</source>
        <translation>No se puede resolver la dirección de -externalip: '%s'</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation>Error al cargar wallet.dat: el monedero está dañado</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation>Error al cargar wallet.dat</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Cargando direcciones...</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %d, %s)</source>
        <translation>No es posible conectar con %s en este sistema (bind ha dado el error %d, %s)</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>Cuantía no válida</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>La red especificada en -onlynet '%s' es desconocida</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Fondos insuficientes</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Cargando el índice de bloques...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Cargando monedero...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>No se puede escribir la dirección predeterminada</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Reexplorando...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Generado pero no aceptado</translation>
    </message>
    </context>
</TS>